==> AminoXZ-1.1.8.5.tar.gz: AminoXZ-1.1.8.5/AminoXZ/lib/util/headers.py <==
from .generator import Generator

class Headers:
	def __init__(self, deviceId: str = None, sid: str = None):
		self.deviceId = deviceId
		self.sid=sid
		self.device = Generator().getDeviceId()
		self.User_Agent_Iphone, self.User_Agent_Android = self.device["iphone_user_agent"], self.device["android_user_agent"]

	def iphone_headers(self, data = None, content_type = None):

		headers = {
			"NDCDEVICEID": self.deviceId if self.deviceId is not None else self.device["device_id"],
			"NDCLANG": "ru",
			"Accept-Language": "ru-RU",
			"SMDEVICEID": "20230109055041eecd2b9dd8439235afe4522cb5dacd26011dba6bbfeeb752", 
			"User-Agent": self.User_Agent_Iphone,
			"Content-Type": "application/json; charset=utf-8",
			"Host": "service.narvii.com",
			"Accept-Encoding": "gzip",
			"Connection": "Upgrade"
			}


		if data is not None:
			headers["Content-Length"] = str(len(data))
			headers["NDC-MSG-SIG"] = Generator().signature(data=data)

		if self.sid:headers["NDCAUTH"] = f"sid={self.sid}"

		if content_type:headers["Content-Type"] = content_type

		return headers

	def android_headers(self, data = None, content_type = None):

		headers = {
			"NDCDEVICEID": self.deviceId if self.deviceId is not None else self.device["device_id"],
			"Accept-Language": "en-US",
			"Content-Type": "application/json; charset=utf-8",
			"User-Agent": self.User_Agent_Android,
			"Host": "service.narvii.com",
			"Accept-Encoding": "gzip",
			"Connection": "Upgrade"
		}

		if data:
			headers["Content-Length"] = str(len(data))
			headers["NDC-MSG-SIG"] = Generator().signature(data=data)

		if self.sid: headers["NDCAUTH"] = f"sid={self.sid}"
		if content_type: headers["Content-Type"] = type


		return headers



	def iphoneWeb_headers(self):
		return None

	def web_headers(self):
		return None

==> AminoXZ-1.1.9.tar.gz: AminoXZ-1.1.9/AminoXZ/lib/util/headers.py <==
from .generator import Generator

class Headers:
	def __init__(self, deviceId: str = None, sid: str = None):
		self.deviceId = deviceId
		self.sid=sid
		self.device = Generator().getDeviceId()
		self.User_Agent_Iphone, self.User_Agent_Android = self.device["iphone_user_agent"], self.device["android_user_agent"]

	def iphone_headers(self, data = None, content_type = None):

		headers = {
			"NDCDEVICEID": self.deviceId if self.deviceId is not None else self.device["device_id"],
			"NDCLANG": "ru",
			"Accept-Language": "ru-RU",
			"SMDEVICEID": "20230109055041eecd2b9dd8439235afe4522cb5dacd26011dba6bbfeeb752", 
			"User-Agent": self.User_Agent_Iphone,
			"Content-Type": "application/json; charset=utf-8",
			"Host": "service.narvii.com",
			"Accept-Encoding": "gzip",
			"Connection": "Upgrade"
			}


		if data is not None:
			headers["Content-Length"] = str(len(data))
			headers["NDC-MSG-SIG"] = Generator().signature(data=data)

		if self.sid:headers["NDCAUTH"] = f"sid={self.sid}"

		if content_type:headers["Content-Type"] = content_type

		return headers

	def android_headers(self, data = None, content_type = None):

		headers = {
			"NDCDEVICEID": self.deviceId if self.deviceId is not None else self.device["device_id"],
			"Accept-Language": "en-US",
			"Content-Type": "application/json; charset=utf-8",
			"User-Agent": self.User_Agent_Android,
			"Host": "service.narvii.com",
			"Accept-Encoding": "gzip",
			"Connection": "Upgrade"
		}

		if data:
			headers["Content-Length"] = str(len(data))
			headers["NDC-MSG-SIG"] = Generator().signature(data=data)

		if self.sid: headers["NDCAUTH"] = f"sid={self.sid}"
		if content_type: headers["Content-Type"] = type


		return headers



	def iphoneWeb_headers(self):
		return None

	def web_headers(self, referer: str):
		headers = {
			"user-agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Ubuntu Chromium/73.0.3683.86 Chrome/73.0.3683.86 Safari/537.36",
			"content-type": "application/json",
			"x-requested-with": "xmlhttprequest",
			"cookie": f"sid={self.sid}",
			"referer": referer
		}

		return headers
